## 1.0.1 (2022-10-13)

- Updated setup.py and tools

## 1.0.0 (2022-10-13)

- Initialized package
- Added Vault backend
- Added File backend (YAML format)
- Added Dict backend
- Added Environment backend
- Added explicit type conversion support (str, bool, int, float)
